@@ -8,7 +8,7 @@ no warnings;
 use Module::Patch 0.12 qw();
 use base qw(Module::Patch);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %config;
 
@@ -46,7 +46,7 @@ HTTP::Headers::Patch::DontUseStorable - Do not use Storable
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -65,6 +65,18 @@ This patch avoids using Storable and clone using the alternative method.
 
 =head1 FAQ
 
+=head2 Is this a bug with HTTP::Headers? Why don't you submit a bug to HTTP-Message?
+
+I tend not to think this is a bug with HTTP::Headers; after all, Storable's
+dclone() is a pretty standard way to clone data in Perl. This patch is more of a
+workaround for current Storable's deficiencies.
+
+=head2 Shouldn't you add STORABLE_{freeze,thaw} methods to Regexp instead?
+
+Yes, that's also one possible solution, albeit with slightly more work. There's
+an old distribution, L<Regexp::Copy> (last release is 0.06 in 2003, at the time
+of this writing) which does this, but last time I tried it no longer works.
+
 =head1 SEE ALSO
 
 =head1 AUTHOR
